document.addEventListener('DOMContentLoaded', () => {
    // Retrieve stored values from chrome.storage.local
    chrome.storage.local.get(['apiKey', 'assistantId', 'threadId'], (data) => {
      console.log("Loaded storage data: ", data);
      document.getElementById('apiKey').value = data.apiKey || '';
      document.getElementById('assistantId').value = data.assistantId || '';
      document.getElementById('threadId').value = data.threadId || '';
    });
  });
  
  document.getElementById('startBtn').addEventListener('click', () => {
    const startBtn = document.getElementById('startBtn');
    const statusDiv = document.getElementById('status');
    const apiKey = document.getElementById('apiKey').value;
    const assistantId = document.getElementById('assistantId').value;
    const threadId = document.getElementById('threadId').value;
  
    // Store values in chrome.storage.local
    chrome.storage.local.set({ apiKey, assistantId, threadId }, () => {
      console.log("Stored API Key, Assistant ID, and Thread ID.");
    });
  
    if (startBtn.textContent === "Start Speech to Text") {
      startBtn.textContent = "Stop Speech to Text";
      statusDiv.style.display = "block";
      startTimer();
      console.log("Sending start message to background script.");
      chrome.runtime.sendMessage({ action: "startSpeechToText", apiKey, assistantId, threadId });
    } else {
      startBtn.textContent = "Start Speech to Text";
      statusDiv.style.display = "none";
      stopTimer();
      console.log("Sending stop message to background script.");
      chrome.runtime.sendMessage({ action: "stopSpeechToText" });
    }
  });
  
  chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    console.log("Popup received a message:", request);
    if (request.action === "recordingStopped") {
      document.getElementById('startBtn').textContent = "Start Speech to Text";
      document.getElementById('status').style.display = "none";
      stopTimer();
    } else if (request.action === "updateThreadId") {
      document.getElementById('threadId').value = request.threadId;
      // Store the updated threadId in chrome.storage.local
      chrome.storage.local.set({ threadId: request.threadId });
    }
  });
  
  let timerInterval;
  
  function startTimer() {
    const timer = document.getElementById('timer');
    const progressBar = document.getElementById('progress-bar');
    const HARD_TIMEOUT = 6 * 60 * 1000; // 6 minutes in milliseconds
    const SILENCE_TIMEOUT = 3000; // 3 seconds in milliseconds
    let startTime = Date.now();
  
    // Clear any existing interval to prevent multiple intervals from running
    if (timerInterval) {
      clearInterval(timerInterval);
    }
  
    timerInterval = setInterval(() => {
      const elapsedTime = Date.now() - startTime;
      const remainingTime = HARD_TIMEOUT - elapsedTime;
  
      if (remainingTime <= 0) {
        clearInterval(timerInterval);
        document.getElementById('startBtn').textContent = "Start Speech to Text";
        document.getElementById('status').style.display = "none";
        chrome.runtime.sendMessage({ action: "stopSpeechToText" });
      }
  
      timer.textContent = `Remaining time: ${(remainingTime / 1000).toFixed(0)} seconds`;
      progressBar.style.width = `${(elapsedTime / HARD_TIMEOUT) * 100}%`;
    }, 1000);
  }
  
  function stopTimer() {
    const timer = document.getElementById('timer');
    const progressBar = document.getElementById('progress-bar');
    timer.textContent = '';
    progressBar.style.width = '0%';
  
    // Clear the interval to stop the timer
    if (timerInterval) {
      clearInterval(timerInterval);
      timerInterval = null;
    }
  }
  